@@ -1,9 +1,9 @@
 /* 
  *  Contacts - A small libebook-based address book.
  *
- *  Authored By Chris Lord <chris@o-hand.com>
+ *  Authored By Chris Lord <chris@linux.intel.com>
  *
- *  Copyright (c) 2005 OpenedHand Ltd - http://o-hand.com
+ *  Copyright (c) 2005, 2009 Intel Corporation
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -112,6 +112,7 @@ typedef struct {
 	GtkListStore *contacts_liststore;
 	GtkTreeModelFilter *contacts_filter;
 	gboolean initialising;
+	gchar *uid_for_startup;
 } ContactsData;
 
 typedef struct {
